@@ -240,10 +240,7 @@ class AddNodeFlow(discord.ui.View):
         await self.host_prompt.responded.wait()
         if match := URL_REGEX.match(self.host_prompt.response):
             protocol = match.group(0)
-            if protocol == "https":
-                self.ssl = True
-            else:
-                self.ssl = False
+            self.ssl = protocol == "https"
             self.host = match.group(1)
         else:
             self.host = self.host_prompt.response
@@ -405,12 +402,12 @@ class NodePickerMenu(BaseMenu):
         self.add_item(self.backward_button)
         self.add_item(self.forward_button)
         self.add_item(self.last_button)
-        if self.source.select_options:  # type: ignore
-            options = self.source.select_options  # type: ignore
+        if self.source.select_options:
+            options = self.source.select_options
             self.remove_item(self.select_view)
             self.select_view = self.selector_cls(options, self.cog, self.selector_text, self.source.select_mapping)
             self.add_item(self.select_view)
-        if self.select_view and not self.source.select_options:  # type: ignore
+        if self.select_view and not self.source.select_options:
             self.remove_item(self.select_view)
             self.select_view = None
 
@@ -689,10 +686,7 @@ class NodeManagerMenu(BaseMenu):
         await self.host_prompt.responded.wait()
         if match := URL_REGEX.match(self.host_prompt.response):
             protocol = match.group(0)
-            if protocol == "https":
-                self.ssl = True
-            else:
-                self.ssl = False
+            self.ssl = protocol == "https"
             self.host = match.group(1)
         else:
             self.host = self.host_prompt.response
